@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2022 Arm Limited.
+ * Copyright (c) 2018-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_GPUTARGET_H
-#define ARM_COMPUTE_GPUTARGET_H
+#ifndef ACL_ARM_COMPUTE_CORE_GPUTARGET_H
+#define ACL_ARM_COMPUTE_CORE_GPUTARGET_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "support/Traits.h"
 
@@ -33,26 +37,45 @@ namespace arm_compute
 /** Available GPU Targets */
 enum class GPUTarget
 {
-    UNKNOWN       = 0x101,
-    GPU_ARCH_MASK = 0xF00,
-    MIDGARD       = 0x100,
-    BIFROST       = 0x200,
-    VALHALL       = 0x300,
-    T600          = 0x110,
-    T700          = 0x120,
-    T800          = 0x130,
-    G71           = 0x210,
-    G72           = 0x220,
-    G51           = 0x230,
-    G51BIG        = 0x231,
-    G51LIT        = 0x232,
-    G52           = 0x240,
-    G52LIT        = 0x241,
-    G31           = 0x242,
-    G76           = 0x250,
-    G77           = 0x310,
-    G78           = 0x320,
-    G710          = 0x330,
+    UNKNOWN             = 0x101,
+    GPU_ARCH_MASK       = 0xF00,
+    GPU_GENERATION_MASK = 0x0F0,
+    MIDGARD             = 0x100,
+    BIFROST             = 0x200,
+    VALHALL             = 0x300,
+    FIFTHGEN            = 0x400,
+    T600                = 0x110,
+    T700                = 0x120,
+    T800                = 0x130,
+    G71                 = 0x210,
+    G72                 = 0x220,
+    G51                 = 0x221,
+    G51BIG              = 0x222,
+    G51LIT              = 0x223,
+    G31                 = 0x224,
+    G76                 = 0x230,
+    G52                 = 0x231,
+    G52LIT              = 0x232,
+    G77                 = 0x310,
+    G57                 = 0x311,
+    G78                 = 0x320,
+    G68                 = 0x321,
+    G78AE               = 0x330,
+    G710                = 0x340,
+    G610                = 0x341,
+    G510                = 0x342,
+    G310                = 0x343,
+    G715                = 0x350,
+    G615                = 0x351,
+    G720                = 0x410,
+    G620                = 0x411,
+
+    // When new models are added, watch out for heuristics.
+    // The default/unrecognized Gpu will be the latest one and
+    // heuristics are using LATEST in their logic. When a new
+    // model is added here, and in the relevant functions,
+    // heuristic behavior will change.
+    // Example heuristic: ClGemmDefaultConfigReshapedRhsOnlyValhall.cpp
 };
 
 /** Enable bitwise operations on GPUTarget enumerations */
@@ -105,4 +128,4 @@ inline bool gpu_target_is_in(GPUTarget target_to_check, GPUTarget target)
     return target_to_check == target;
 }
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_GPUTARGET_H */
+#endif // ACL_ARM_COMPUTE_CORE_GPUTARGET_H
