@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2021, 2023 Arm Limited.
+ * Copyright (c) 2016-2021, 2023, 2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_PIXELVALUE_H
-#define ARM_COMPUTE_PIXELVALUE_H
+#ifndef ACL_ARM_COMPUTE_CORE_PIXELVALUE_H
+#define ACL_ARM_COMPUTE_CORE_PIXELVALUE_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/QuantizationInfo.h"
 #include "arm_compute/core/Types.h"
@@ -330,4 +334,4 @@ public:
     }
 };
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_PIXELVALUE_H */
+#endif // ACL_ARM_COMPUTE_CORE_PIXELVALUE_H
