@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2024 Arm Limited.
+ * Copyright (c) 2016-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -24,6 +24,10 @@
 #ifndef ACL_ARM_COMPUTE_CORE_TENSORINFO_H
 #define ACL_ARM_COMPUTE_CORE_TENSORINFO_H
 
+/** @file
+ * @publicapi
+ */
+
 #include "arm_compute/core/Coordinates.h"
 #include "arm_compute/core/Helpers.h"
 #include "arm_compute/core/ITensorInfo.h"
@@ -274,6 +278,13 @@ public:
     {
         return _is_resizable;
     }
+    ITensorInfo &set_dynamic(bool dynamic) override
+    {
+        std::fill(std::begin(_dims_state), std::end(_dims_state),
+                  (dynamic ? get_dynamic_state_value() : get_static_state_value()));
+
+        return *this;
+    }
     bool is_dynamic() const override
     {
         return std::find(std::cbegin(_dims_state), std::cend(_dims_state), get_dynamic_state_value()) !=
@@ -327,6 +338,9 @@ public:
 
 private:
     /** Calculates strides, offset and total size resulting from the specified padding around the XY plane.
+     *
+     * @note When interpreting the required_strides in the return value, only the values up to the corresponding dimension in the tensor is
+     *       valid. For example, 1D tensor should only refer to 1D in required_strides, 2D tensor up to 2D in required_strides, and so on.
      *
      * @param[in] padding Padding around the XY plane in elements.
      */
