@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2016-2021, 2023 Arm Limited.
+ * Copyright (c) 2016-2021, 2023-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLPIXELWISEMULTIPLICATION_H
-#define ARM_COMPUTE_CLPIXELWISEMULTIPLICATION_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLPIXELWISEMULTIPLICATION_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLPIXELWISEMULTIPLICATION_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/Rounding.h"
 #include "arm_compute/function_info/ActivationLayerInfo.h"
@@ -36,7 +40,7 @@ class CLCompileContext;
 class ICLTensor;
 class ITensorInfo;
 
-/** Basic function to run @ref opencl::ClMul. */
+/** Basic function to run opencl::ClMul. */
 class CLPixelWiseMultiplication : public IFunction
 {
 public:
@@ -142,7 +146,7 @@ private:
     std::unique_ptr<Impl> _impl;
 };
 
-/** Basic function to run @ref opencl::ClComplexMul. */
+/** Basic function to run opencl::ClComplexMul. */
 class CLComplexPixelWiseMultiplication : public IFunction
 {
 public:
@@ -206,4 +210,4 @@ private:
     std::unique_ptr<Impl> _impl;
 };
 } // namespace arm_compute
-#endif /*ARM_COMPUTE_CLPIXELWISEMULTIPLICATION_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLPIXELWISEMULTIPLICATION_H
