@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2018-2021 Arm Limited.
+ * Copyright (c) 2018-2021, 2024-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -21,8 +21,12 @@
  * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
  * SOFTWARE.
  */
-#ifndef ARM_COMPUTE_CLTILE_H
-#define ARM_COMPUTE_CLTILE_H
+#ifndef ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTILE_H
+#define ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTILE_H
+
+/** @file
+ * @publicapi
+ */
 
 #include "arm_compute/core/Types.h"
 #include "arm_compute/runtime/CL/ICLSimpleFunction.h"
@@ -33,7 +37,7 @@ class CLCompileContext;
 class ICLTensor;
 class ITensorInfo;
 
-/** Basic function to run @ref CLTileKernel */
+/** Basic function to run CLTileKernel */
 class CLTile : public ICLSimpleFunction
 {
 public:
@@ -74,4 +78,4 @@ public:
     static Status validate(const ITensorInfo *input, const ITensorInfo *output, const Multiples &multiples);
 };
 } // namespace arm_compute
-#endif /* ARM_COMPUTE_CLTILE_H */
+#endif // ACL_ARM_COMPUTE_RUNTIME_CL_FUNCTIONS_CLTILE_H
