@@ -1,5 +1,5 @@
 /*
- * Copyright (c) 2017-2024 Arm Limited.
+ * Copyright (c) 2017-2025 Arm Limited.
  *
  * SPDX-License-Identifier: MIT
  *
@@ -37,18 +37,11 @@
 #include "arm_compute/core/Strides.h"
 #include "arm_compute/core/TensorInfo.h"
 #include "arm_compute/core/Types.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/CastAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/ClampAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/Conv2dAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/DepthwiseConv2dAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/Pool2dAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/ResizeAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/attributes/SoftmaxAttributes.h"
-#include "arm_compute/dynamic_fusion/sketch/gpu/operators/GpuPool2d.h"
 #include "arm_compute/function_info/ConvolutionInfo.h"
 #include "arm_compute/function_info/FullyConnectedLayerInfo.h"
 #include "arm_compute/function_info/GEMMInfo.h"
 #include "arm_compute/function_info/MatMulInfo.h"
+#include "arm_compute/function_info/ScatterInfo.h"
 #include "arm_compute/runtime/CL/CLTunerTypes.h"
 #include "arm_compute/runtime/CL/CLTypes.h"
 #include "arm_compute/runtime/common/LSTMParams.h"
@@ -3288,247 +3281,6 @@ inline std::string to_string(const Padding2D &padding2d)
     return str.str();
 }
 
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::Pool2dAttributes type.
- *
- * @param[out] os          Output stream.
- * @param[in]  pool2d_attr arm_compute::experimental::dynamic_fusion::Pool2dAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream &os, const experimental::dynamic_fusion::Pool2dAttributes &pool2d_attr)
-{
-    os << "Pool2dAttributes="
-       << "["
-       << "PoolingType=" << pool2d_attr.pool_type() << ","
-       << "PoolSize=" << pool2d_attr.pool_size() << ","
-       << "Padding=" << pool2d_attr.pad() << ","
-       << "Stride=" << pool2d_attr.stride() << ","
-       << "ExcludePadding" << pool2d_attr.exclude_padding() << "]";
-
-    return os;
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::Pool2dAttributes type.
- *
- * @param[in] pool2d_attr arm_compute::experimental::dynamic_fusion::Pool2dAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::Pool2dAttributes &pool2d_attr)
-{
-    std::stringstream str;
-    str << pool2d_attr;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::GpuPool2dSettings type
- *
- * @param[out] os       Output stream
- * @param[in]  settings arm_compute::dynamic_fusion::GpuPool2dSettings type to output
- */
-inline ::std::ostream &operator<<(::std::ostream &os, const experimental::dynamic_fusion::GpuPool2dSettings &settings)
-{
-    os << "Settings="
-       << "["
-       << "UseInfAsLimit=" << settings.use_inf_as_limit() << "]";
-    return os;
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::GpuPool2dSettings type.
- *
- * @param[in] settings arm_compute::experimental::dynamic_fusion::GpuPool2dSettings type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::GpuPool2dSettings &settings)
-{
-    std::stringstream str;
-    str << settings;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::Conv2dAttributes type.
- *
- * @param[out] os          Output stream.
- * @param[in]  conv2d_attr arm_compute::experimental::dynamic_fusion::Conv2dAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream &os, const experimental::dynamic_fusion::Conv2dAttributes &conv2d_attr)
-{
-    os << "Conv2dAttributes="
-       << "["
-       << "Padding=" << conv2d_attr.pad() << ", "
-       << "Size2D=" << conv2d_attr.stride() << ", "
-       << "Dialation=" << conv2d_attr.dilation() << "]";
-
-    return os;
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::Conv2dAttributes type.
- *
- * @param[in] conv2d_attr arm_compute::experimental::dynamic_fusion::Conv2dAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::Conv2dAttributes &conv2d_attr)
-{
-    std::stringstream str;
-    str << conv2d_attr;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::CastAttributes type.
- *
- * @param[out] os        Output stream.
- * @param[in]  cast_attr arm_compute::experimental::dynamic_fusion::CastAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream &os, const experimental::dynamic_fusion::CastAttributes &cast_attr)
-{
-    os << "CastAttributes="
-       << "["
-       << "Data Type=" << cast_attr.data_type() << ", "
-       << "Convert Policy=" << cast_attr.convert_policy() << "]";
-
-    return os;
-}
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::CastAttributes type.
- *
- * @param[in] cast_attr arm_compute::experimental::dynamic_fusion::CastAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::CastAttributes &cast_attr)
-{
-    std::stringstream str;
-    str << cast_attr;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::DepthwiseConv2dAttributes type.
- *
- * @param[out] os             Output stream.
- * @param[in]  dw_conv2d_attr arm_compute::experimental::dynamic_fusion::DepthwiseConv2dAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream                                                &os,
-                                  const experimental::dynamic_fusion::DepthwiseConv2dAttributes &dw_conv2d_attr)
-{
-    os << "DepthwiseConv2dAttributes="
-       << "["
-       << "Padding=" << dw_conv2d_attr.pad() << ", "
-       << "Size2D=" << dw_conv2d_attr.stride() << ", "
-       << "Depth Multiplier=" << dw_conv2d_attr.depth_multiplier() << ", "
-       << "Dilation=" << dw_conv2d_attr.dilation() << ","
-       << "DimensionRoundingType: " << dw_conv2d_attr.dimension_rounding_type() << "]";
-
-    return os;
-}
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::DepthwiseConv2dAttributes type.
- *
- * @param[in] dw_conv2d_attr arm_compute::experimental::dynamic_fusion::DepthwiseConv2dAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::DepthwiseConv2dAttributes &dw_conv2d_attr)
-{
-    std::stringstream str;
-    str << dw_conv2d_attr;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::ClampAttributes type.
- *
- * @param[out] os         Output stream.
- * @param[in]  clamp_attr arm_compute::experimental::dynamic_fusion::ClampAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream &os, const experimental::dynamic_fusion::ClampAttributes &clamp_attr)
-{
-    os << "ClampAttributes="
-       << "["
-       << "Min value=" << clamp_attr.min_val() << ", "
-       << "Max value=" << clamp_attr.max_val() << "]";
-    return os;
-}
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::ClampAttributes type.
- *
- * @param[in] clamp_attr arm_compute::experimental::dynamic_fusion::ClampAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::ClampAttributes &clamp_attr)
-{
-    std::stringstream str;
-    str << clamp_attr;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::ResizeAttributes type.
- *
- * @param[out] os          Output stream.
- * @param[in]  resize_attr arm_compute::experimental::dynamic_fusion::ResizeAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream &os, const experimental::dynamic_fusion::ResizeAttributes &resize_attr)
-{
-    os << "ResizeAttributes="
-       << "["
-       << "AlignCorners=" << resize_attr.align_corners() << ", "
-       << "InterpolationPolicy=" << resize_attr.interpolation_policy() << ", "
-       << "OutputHeight=" << resize_attr.output_height() << ", "
-       << "OutputWidth=" << resize_attr.output_width() << ", "
-       << "SamplingPolicy=" << resize_attr.sampling_policy() << "]";
-    return os;
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::ResizeAttributes type.
- *
- * @param[in] resize_attr arm_compute::experimental::dynamic_fusion::ResizeAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::ResizeAttributes &resize_attr)
-{
-    std::stringstream str;
-    str << resize_attr;
-    return str.str();
-}
-
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::SoftmaxAttributes type.
- *
- * @param[out] os           Output stream.
- * @param[in]  softmax_attr arm_compute::experimental::dynamic_fusion::SoftmaxAttributes type to output.
- *
- * @return Modified output stream.
- */
-inline ::std::ostream &operator<<(::std::ostream                                        &os,
-                                  const experimental::dynamic_fusion::SoftmaxAttributes &softmax_attr)
-{
-    os << "SoftmaxAttributes="
-       << "["
-       << "Beta=" << softmax_attr.beta() << ", "
-       << "Is Log Softmax=" << softmax_attr.is_log_softmax() << ", "
-       << "Axis=" << softmax_attr.axis() << "]";
-    return os;
-}
-/** Formatted output of the arm_compute::experimental::dynamic_fusion::SoftmaxAttributes type.
- *
- * @param[in] softmax_attr arm_compute::experimental::dynamic_fusion::SoftmaxAttributes type to output.
- *
- * @return Formatted string.
- */
-inline std::string to_string(const experimental::dynamic_fusion::SoftmaxAttributes &softmax_attr)
-{
-    std::stringstream str;
-    str << softmax_attr;
-    return str.str();
-}
 /** Formatted output of the arm_compute::MatMulInfo type.
  *
  * @param[out] os          Output stream.
@@ -3601,7 +3353,7 @@ inline ::std::ostream &operator<<(::std::ostream &os, const arm_compute::CpuMatM
 {
     os << "CpuMatMulSettings="
        << "["
-       << "fast_math=" << settings.fast_math() << "]";
+       << "fast_math=" << settings.fast_math() << ",fixed_format=" << settings.fixed_format() << "]";
 
     return os;
 }
@@ -3618,6 +3370,88 @@ inline std::string to_string(const arm_compute::CpuMatMulSettings &settings)
     return str.str();
 }
 
+/** Formatted output of the scatter function type.
+ *
+ * @param[out] os       Output stream.
+ * @param[in]  function arm_compute::ScatterFunction type to output.
+ *
+ * @return Modified output stream.
+ */
+inline ::std::ostream &operator<<(::std::ostream &os, const ScatterFunction &function)
+{
+    switch (function)
+    {
+        case ScatterFunction::Update:
+            os << "UPDATE";
+            break;
+        case ScatterFunction::Add:
+            os << "ADD";
+            break;
+        case ScatterFunction::Sub:
+            os << "SUB";
+            break;
+        case ScatterFunction::Max:
+            os << "MAX";
+            break;
+        case ScatterFunction::Min:
+            os << "MIN";
+            break;
+        default:
+            ARM_COMPUTE_ERROR("NOT_SUPPORTED!");
+    }
+    return os;
+}
+/** Formatted output of the arm_compute::ScatterFunction type.
+ *
+ * @param[in] func arm_compute::ScatterFunction type to output.
+ *
+ * @return Formatted string.
+ */
+inline std::string to_string(const arm_compute::ScatterFunction &func)
+{
+    std::stringstream str;
+    str << func;
+    return str.str();
+}
+/** Formatted output of the arm_compute::ScatterInfo type.
+ *
+ * @param[out] os   Output stream.
+ * @param[in]  info arm_compute::ScatterInfo  type to output.
+ *
+ * @return Modified output stream.
+ */
+inline ::std::ostream &operator<<(::std::ostream &os, const arm_compute::ScatterInfo &info)
+{
+    os << "ScatterInfo="
+       << "["
+       << "Function=" << info.func << ", "
+       << "InitialiseZero=" << info.zero_initialization << "] ";
+    return os;
+}
+/** Formatted output of the arm_compute::ScatterInfo type.
+ *
+ * @param[in] info arm_compute::ScatterInfo type to output.
+ *
+ * @return Formatted string.
+ */
+inline std::string to_string(const arm_compute::ScatterInfo &info)
+{
+    std::stringstream str;
+    str << info;
+    return str.str();
+}
+
+/** Formatted output of the bool data type.
+ *
+ * @param[in] info bool type to output.
+ *
+ * @return Formatted string
+ */
+inline std::string to_string(const bool &info)
+{
+    return info ? "true" : "false";
+}
+
 } // namespace arm_compute
 
 #endif // ACL_UTILS_TYPEPRINTER_H
